TorusEInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: TorusEInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TorusEInteraction.func

   .. rubric:: Methods Documentation

   .. automethod:: func
